==> dde-network-core_1.0.69.orig.tar.xz: dde-network-core-1.0.69/dss-network-plugin/translations/dss-network-plugin_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nová zpráva</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Připojování k %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 připojeno</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 odpojeno</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Nedaří se připojit k %1 – zkontrolujte síťové zařízení a kabely prosím.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Nelze se připojit k %1. Přesuňte se blíže k bezdrátovému přístupovému bodu</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Připojení k %1 se nezdařilo – chybné heslo</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Pro připojení se k %1 je požadováno heslo</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN síť nebyla nalezena</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Drátové připojení</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpečení</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Připojeno, ale bez přístupu k Internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Ověřování</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Získávání IP adresy</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP adres</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nepodařilo se</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Získávání adresy</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Drátová síť %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrátová síť %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Připojeno, ale bez přístupu k Internetu</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Připojení se nezdařilo</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Střet IP adres</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Vypnout drátové připojení</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Zapnout drátové připojení</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vypnout bezdrátové připojení</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Zapnout bezdrátové připojení</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Zakázat síť</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Povolit síť</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavení sítě</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dss-network-plugin/translations/dss-network-plugin_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nová zpráva</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Připojování k %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 připojeno</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 odpojeno</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Nedaří se připojit k %1 – zkontrolujte síťové zařízení a kabely prosím.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Nelze se připojit k %1. Přesuňte se blíže k bezdrátovému přístupovému bodu</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Připojení k %1 se nezdařilo – chybné heslo</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Pro připojení se k %1 je požadováno heslo</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>%1 802.11 WLAN síť nebyla nalezena</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Připojit se ke skryté síti</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Připojit</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Název (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Přípojný bod</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Typ zabezpečení</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska sítě</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Hlavní DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Předpona</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rychlost</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Připojeno, ale bez přístupu k Internetu</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Ověřování</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Získávání IP adresy</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Připojeno</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odpojeno</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Konflikt IP adres</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Nepodařilo se</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Získávání adresy</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Drátová síť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Drátová síť %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrátová síť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrátová síť %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Zařízení zakázáno</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Síťový kabel odpojen</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepřipojeno</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Připojuje se</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Připojeno, ale bez přístupu k Internetu</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Připojení se nezdařilo</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Střet IP adres</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Vypnout drátové připojení</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Zapnout drátové připojení</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Vypnout bezdrátové připojení</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Zapnout bezdrátové připojení</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Zakázat síť</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Povolit síť</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Nastavení sítě</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Drátové připojení</translation>
    </message>
</context>
</TS>
